@@ -1,3 +1,4 @@
+"""Print loaded configurations."""
 import rich
 
 from .. import configs
@@ -6,9 +7,10 @@ from ._base import command
 
 @command.command("configs")
 def subcommand():
-    """Query loaded configurations."""
+    """Print loaded configurations."""
     main()
 
 
 def main():
+    """Print loaded configurations."""
     rich.print(configs.configs)
